#  ::: enzax.rate_equations
    options:
      show_root_heading: true
      filters:
        - "!check"
      members:
        - RateEquation
        - Drain
        - IrreversibleMichaelisMenten
        - ReversibleMichaelisMenten
        - AllostericIrreversibleMichaelisMenten
        - AllostericReversibleMichaelisMenten
